/*
 * Copyright (c) 1999, 2022 Tanuki Software, Ltd.
 * http://www.tanukisoftware.com
 * All rights reserved.
 *
 * This software is the proprietary information of Tanuki Software.
 * You shall use it only in accordance with the terms of the
 * license agreement you entered into with Tanuki Software.
 * http://wrapper.tanukisoftware.com/doc/english/licenseOverview.html
 */

#ifndef _LOGGERJNI_H
#define _LOGGERJNI_H

#include "logger_base.h"

void setPrintMessageCallback(int (*callback)(const TCHAR* message));

void log_printf(const TCHAR *lpszFmt, ...);

#endif
